=== modified file 'NEWS'
--- NEWS	2005-10-08 00:39:04 +0000
+++ NEWS	2005-10-08 00:50:43 +0000
@@ -63,6 +63,10 @@
     * InventoryEntry is now an abstract base class, use one of the
       concrete InventoryDirectory etc classes instead.
 
+    * Branch raises an UnsupportedFormatError when it detects a 
+      bzr branch it cannot understand. This allows for precise
+      handling of such circumstances.
+
 
   TESTING:
 

=== modified file 'bzrlib/add.py'
--- bzrlib/add.py	2005-10-03 02:10:02 +0000
+++ bzrlib/add.py	2005-10-08 00:49:13 +0000
@@ -14,12 +14,14 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+from os.path import dirname
+
+import bzrlib.errors as errors
 from bzrlib.inventory import InventoryEntry
 from bzrlib.trace import mutter, note, warning
 from bzrlib.errors import NotBranchError
 from bzrlib.branch import Branch
 from bzrlib.osutils import quotefn
-from os.path import dirname
 
 def glob_expand_for_win32(file_list):
     import glob
@@ -116,6 +118,8 @@
                 sub_tree = True
             except NotBranchError:
                 sub_tree = False
+            except errors.UnsupportedFormatError:
+                sub_tree = True
         else:
             sub_tree = False
 

=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2005-10-07 06:13:14 +0000
+++ bzrlib/branch.py	2005-10-08 00:49:13 +0000
@@ -506,7 +506,8 @@
 
         if (not relax_version_check
             and self._branch_format != 5):
-            raise BzrError('sorry, branch format %r not supported' % fmt,
+            raise errors.UnsupportedFormatError(
+                           'sorry, branch format %r not supported' % fmt,
                            ['use a different bzr version',
                             'or remove the .bzr directory'
                             ' and "bzr init" again'])

=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2005-10-08 00:32:39 +0000
+++ bzrlib/errors.py	2005-10-08 00:49:13 +0000
@@ -65,6 +65,12 @@
         return 'not a branch: %s' % self.args[0]
 
 
+class UnsupportedFormatError(BzrError):
+    """Specified path is a bzr branch that we cannot read."""
+    def __str__(self):
+        return 'unsupported branch format: %s' % self.args[0]
+
+
 class NotVersionedError(BzrError):
     """Specified object is not versioned."""
 

